self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "fed99136f34e5d128988b13f2cd36d2b",
    "url": "/v1/admin/index.html"
  },
  {
    "revision": "16cdb0adf1041cdd526f",
    "url": "/v1/admin/static/css/2.190e409a.chunk.css"
  },
  {
    "revision": "16cdb0adf1041cdd526f",
    "url": "/v1/admin/static/js/2.fc7dc848.chunk.js"
  },
  {
    "revision": "96f1385390314af8d6fa",
    "url": "/v1/admin/static/js/main.bee3cadd.chunk.js"
  },
  {
    "revision": "acbb2857f1ab9b35aaca",
    "url": "/v1/admin/static/js/runtime-main.cf9940cc.js"
  },
  {
    "revision": "448c34a56d699c29117adc64c43affeb",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.448c34a5.woff2"
  },
  {
    "revision": "89889688147bd7575d6327160d64e760",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.89889688.svg"
  },
  {
    "revision": "e18bbf611f2a2e43afc071aa2f4e1512",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.e18bbf61.ttf"
  },
  {
    "revision": "f4769f9bdb7466be65088239c12046d1",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.f4769f9b.eot"
  },
  {
    "revision": "fa2772327f55d8198301fdb8bcfc8158",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.fa277232.woff"
  }
]);